marcoabreu closed pull request #10682: [MX-307] Upgrade timeout to 10 minutes 
per test
URL: https://github.com/apache/incubator-mxnet/pull/10682
 
 
   

This is a PR merged from a forked repository.
As GitHub hides the original diff on merge, it is displayed below for
the sake of provenance:

As this is a foreign pull request (from a fork), the diff is supplied
below (as it won't show otherwise due to GitHub magic):

diff --git a/tests/tutorials/test_tutorials.py 
b/tests/tutorials/test_tutorials.py
index da8d69051aa..11d000a1f89 100644
--- a/tests/tutorials/test_tutorials.py
+++ b/tests/tutorials/test_tutorials.py
@@ -44,9 +44,9 @@
 import sys
 
 
 # Maximum 7 minutes per test
 # Reaching timeout causes a test failure
-TIME_OUT = 7*60
+TIME_OUT = 10*60
 # Pin to ipython version 4
 IPYTHON_VERSION = 4
 temp_dir = 'tmp_notebook'


 

----------------------------------------------------------------
@@ -44,9 +44,9 @@
 
 
-# Maximum 7 minutes per test
+# Maximum 10 minutes per test
 # Reaching timeout causes a test failure
This is an automated message from the Apache Git Service.
To respond to the message, please log on GitHub and use the
URL above to go to the specific comment.
 
For queries about this service, please contact Infrastructure at:
[email protected]


With regards,
Apache Git Services

Reply via email to